@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2017 Zabbix SIA
+** Copyright (C) 2001-2019 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -93,7 +93,6 @@ class ZBase {
 		require_once $this->getRootDir().'/include/db.inc.php';
 
 		// page specific includes
-		require_once $this->getRootDir().'/include/acknow.inc.php';
 		require_once $this->getRootDir().'/include/actions.inc.php';
 		require_once $this->getRootDir().'/include/discovery.inc.php';
 		require_once $this->getRootDir().'/include/draw.inc.php';
@@ -127,13 +126,14 @@ class ZBase {
 				$this->loadConfigFile();
 				$this->initDB();
 				$this->authenticateUser();
-				$this->initLocales();
+				$this->initLocales(CWebUser::$data);
+				$this->setLayoutModeByUrl();
 				break;
 
 			case self::EXEC_MODE_API:
 				$this->loadConfigFile();
 				$this->initDB();
-				$this->initLocales();
+				$this->initLocales(['lang' => 'en_gb']);
 				break;
 
 			case self::EXEC_MODE_SETUP:
@@ -142,7 +142,7 @@ class ZBase {
 					$this->loadConfigFile();
 					$this->initDB();
 					$this->authenticateUser();
-					$this->initLocales();
+					$this->initLocales(CWebUser::$data);
 				}
 				catch (ConfigFileException $e) {}
 				break;
@@ -151,12 +151,32 @@ class ZBase {
 		// new MVC processing, otherwise we continue execution old style
 		if (hasRequest('action')) {
 			$router = new CRouter(getRequest('action'));
+
+			if ($router->getLayout() === 'layout.htmlpage') {
+				$this->checkAssetsCache();
+			}
+
 			if ($router->getController() !== null) {
 				CProfiler::getInstance()->start();
 				$this->processRequest($router);
 				exit;
 			}
 		}
+		elseif ($mode == self::EXEC_MODE_DEFAULT && basename($_SERVER['SCRIPT_NAME']) !== 'cachewarning.php'
+				&& basename($_SERVER['SCRIPT_NAME']) !== 'jsrpc.php') {
+			$this->checkAssetsCache();
+		}
+	}
+
+	/**
+	 * Redirect user to cachewarning.php page if assets cache is not ready.
+	 */
+	public function checkAssetsCache() {
+		if ((new CAssetsFileCache(ZBase::getRootDir()))->build() === false) {
+			redirect('cachewarning.php');
+
+			exit;
+		}
 	}
 
 	/**
@@ -196,6 +216,7 @@ class ZBase {
 			$this->rootDir.'/include/classes/mvc',
 			$this->rootDir.'/include/classes/api',
 			$this->rootDir.'/include/classes/api/services',
+			$this->rootDir.'/include/classes/api/helpers',
 			$this->rootDir.'/include/classes/api/managers',
 			$this->rootDir.'/include/classes/api/clients',
 			$this->rootDir.'/include/classes/api/wrappers',
@@ -212,6 +233,7 @@ class ZBase {
 			$this->rootDir.'/include/classes/export',
 			$this->rootDir.'/include/classes/export/writers',
 			$this->rootDir.'/include/classes/export/elements',
+			$this->rootDir.'/include/classes/graph',
 			$this->rootDir.'/include/classes/graphdraw',
 			$this->rootDir.'/include/classes/import',
 			$this->rootDir.'/include/classes/import/converters',
@@ -231,6 +253,7 @@ class ZBase {
 			$this->rootDir.'/include/classes/tree',
 			$this->rootDir.'/include/classes/html',
 			$this->rootDir.'/include/classes/html/pageheader',
+			$this->rootDir.'/include/classes/html/svg',
 			$this->rootDir.'/include/classes/html/widget',
 			$this->rootDir.'/include/classes/html/interfaces',
 			$this->rootDir.'/include/classes/parsers',
@@ -243,7 +266,8 @@ class ZBase {
 			$this->rootDir.'/include/classes/regexp',
 			$this->rootDir.'/include/classes/ldap',
 			$this->rootDir.'/include/classes/pagefilter',
-			$this->rootDir.'/include/classes/widgetfields',
+			$this->rootDir.'/include/classes/widgets/fields',
+			$this->rootDir.'/include/classes/widgets/forms',
 			$this->rootDir.'/include/classes/widgets',
 			$this->rootDir.'/local/app/controllers',
 			$this->rootDir.'/app/controllers'
@@ -259,6 +283,8 @@ class ZBase {
 		return [
 			'blue-theme' => _('Blue'),
 			'dark-theme' => _('Dark'),
+			'hc-light' => _('High-contrast light'),
+			'hc-dark' => _('High-contrast dark')
 		];
 	}
 
@@ -302,8 +328,11 @@ class ZBase {
 
 	/**
 	 * Initialize translations.
+	 *
+	 * @param array  $user_data          Array of user data.
+	 * @param string $user_data['lang']  Language.
 	 */
-	protected function initLocales() {
+	protected function initLocales(array $user_data) {
 		init_mbstrings();
 
 		$defaultLocales = [
@@ -312,7 +341,7 @@ class ZBase {
 
 		if (function_exists('bindtextdomain')) {
 			// initializing gettext translations depending on language selected by user
-			$locales = zbx_locale_variants(CWebUser::$data['lang']);
+			$locales = zbx_locale_variants($user_data['lang']);
 			$locale_found = false;
 			foreach ($locales as $locale) {
 				// since LC_MESSAGES may be unavailable on some systems, try to set all of the locales
@@ -324,7 +353,6 @@ class ZBase {
 
 				if (setlocale(LC_ALL, $locale)) {
 					$locale_found = true;
-					CWebUser::$data['locale'] = $locale;
 					break;
 				}
 			}
@@ -335,8 +363,8 @@ class ZBase {
 			// this will be unnecessary in PHP 5.5
 			setlocale(LC_CTYPE, $defaultLocales);
 
-			if (!$locale_found && CWebUser::$data['lang'] != 'en_GB' && CWebUser::$data['lang'] != 'en_gb') {
-				error('Locale for language "'.CWebUser::$data['lang'].'" is not found on the web server. Tried to set: '.implode(', ', $locales).'. Unable to translate Zabbix interface.');
+			if (!$locale_found && $user_data['lang'] != 'en_GB' && $user_data['lang'] != 'en_gb') {
+				error('Locale for language "'.$user_data['lang'].'" is not found on the web server. Tried to set: '.implode(', ', $locales).'. Unable to translate Zabbix interface.');
 			}
 			bindtextdomain('frontend', 'locale');
 			bind_textdomain_codeset('frontend', 'UTF-8');
@@ -354,14 +382,14 @@ class ZBase {
 	 * Authenticate user.
 	 */
 	protected function authenticateUser() {
-		$sessionId = CWebUser::checkAuthentication(CWebUser::getSessionCookie());
+		$sessionid = CWebUser::checkAuthentication(CWebUser::getSessionCookie());
 
-		if (!$sessionId) {
+		if (!$sessionid) {
 			CWebUser::setDefault();
 		}
 
 		// set the authentication token for the API
-		API::getWrapper()->auth = $sessionId;
+		API::getWrapper()->auth = $sessionid;
 
 		// enable debug mode in the API
 		API::getWrapper()->debug = CWebUser::getDebugMode();
@@ -393,7 +421,6 @@ class ZBase {
 				$data['page']['file'] = $response->getFileName();
 				$data['controller']['action'] = $router->getAction();
 				$data['main_block'] = $view->getOutput();
-				$data['fullscreen'] = isset($_REQUEST['fullscreen']) && $_REQUEST['fullscreen'] == 1 ? 1 : 0;
 				$data['javascript']['files'] = $view->getAddedJS();
 				$data['javascript']['pre'] = $view->getIncludedJS();
 				$data['javascript']['post'] = $view->getPostJS();
@@ -423,12 +450,19 @@ class ZBase {
 		// Controller returned fatal error
 		else if ($response instanceof CControllerResponseFatal) {
 			header('Content-Type: text/html; charset=UTF-8');
+
+			global $ZBX_MESSAGES;
+			$messages = (isset($ZBX_MESSAGES) && $ZBX_MESSAGES) ? filter_messages($ZBX_MESSAGES) : [];
+			foreach ($messages as $message) {
+				$response->addMessage($message['message']);
+			}
+
 			$response->addMessage('Controller: '.$router->getAction());
 			ksort($_REQUEST);
 			foreach ($_REQUEST as $key => $value) {
 				// do not output SID
 				if ($key != 'sid') {
-					$response->addMessage($key.': '.$value);
+					$response->addMessage(is_scalar($value) ? $key.': '.$value : $key.': '.gettype($value));
 				}
 			}
 			CSession::setValue('messages', $response->getMessages());
@@ -436,4 +470,19 @@ class ZBase {
 			redirect('zabbix.php?action=system.warning');
 		}
 	}
+
+	/**
+	 * Set layout to fullscreen or kiosk mode if URL contains 'fullscreen' and/or 'kiosk' arguments.
+	 */
+	private function setLayoutModeByUrl() {
+		if (array_key_exists('kiosk', $_GET) && $_GET['kiosk'] === '1') {
+			CView::setLayoutMode(ZBX_LAYOUT_KIOSKMODE);
+		}
+		elseif (array_key_exists('fullscreen', $_GET)) {
+			CView::setLayoutMode($_GET['fullscreen'] === '1' ? ZBX_LAYOUT_FULLSCREEN : ZBX_LAYOUT_NORMAL);
+		}
+
+		// Remove $_GET arguments to prevent CUrl from generating URL with 'fullscreen'/'kiosk' arguments.
+		unset($_GET['fullscreen'], $_GET['kiosk']);
+	}
 }
