@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2018 Zabbix SIA
+** Copyright (C) 2001-2019 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -121,14 +121,14 @@ class CDashboardWidgetMap extends CDiv {
 		if ($this->current_sysmapid !== null && $this->initial_load) {
 			// This should be before other scripts.
 			$script_run .=
-				'jQuery(".dashbrd-grid-widget-container").dashboardGrid('.
+				'jQuery(".dashbrd-grid-container").dashboardGrid('.
 					'\'setWidgetStorageValue\', "'.$this->uniqueid.'", \'current_sysmapid\', '.$this->current_sysmapid.
 				');';
 		}
 
 		if ($this->initial_load) {
 			$script_run .=
-				'jQuery(".dashbrd-grid-widget-container").dashboardGrid("addAction", "timer_refresh", '.
+				'jQuery(".dashbrd-grid-container").dashboardGrid("addAction", "timer_refresh", '.
 					'"zbx_sysmap_widget_trigger", "'.$this->uniqueid.'", {'.
 						'parameters: ["onWidgetRefresh"],'.
 						'grid: {widget: 1},'.
@@ -137,7 +137,7 @@ class CDashboardWidgetMap extends CDiv {
 				');';
 
 			$script_run .=
-				'jQuery(".dashbrd-grid-widget-container").dashboardGrid("addAction", "afterUpdateWidgetConfig", '.
+				'jQuery(".dashbrd-grid-container").dashboardGrid("addAction", "afterUpdateWidgetConfig", '.
 					'"zbx_sysmap_widget_trigger", "'.$this->uniqueid.'", {'.
 						'parameters: ["afterUpdateWidgetConfig"],'.
 						'grid: {widget: 1},'.
@@ -149,28 +149,24 @@ class CDashboardWidgetMap extends CDiv {
 		if ($this->source_type == WIDGET_SYSMAP_SOURCETYPE_FILTER && $this->filter_widget_reference
 				&& $this->initial_load) {
 			$script_run .=
-				'jQuery(".dashbrd-grid-widget-container").dashboardGrid(\'registerDataExchange\', {'.
+				'jQuery(".dashbrd-grid-container").dashboardGrid(\'registerDataExchange\', {'.
 					'uniqueid: "'.$this->uniqueid.'",'.
 					'linkedto: "'.$this->filter_widget_reference.'",'.
 					'data_name: "selected_mapid",'.
 					'callback: function(widget, data) {'.
-						'if (data[0].mapid !== +data[0].mapid) {'.
-							'return;'.
-						'}'.
-
-						'jQuery(".dashbrd-grid-widget-container").dashboardGrid(\'setWidgetStorageValue\', '.
+						'jQuery(".dashbrd-grid-container").dashboardGrid(\'setWidgetStorageValue\', '.
 							'widget.uniqueid, \'current_sysmapid\', data[0].mapid'.
 						');'.
-						'jQuery(".dashbrd-grid-widget-container").dashboardGrid(\'setWidgetStorageValue\', '.
+						'jQuery(".dashbrd-grid-container").dashboardGrid(\'setWidgetStorageValue\', '.
 							'widget.uniqueid, \'previous_maps\', ""'.
 						');'.
-						'jQuery(".dashbrd-grid-widget-container").dashboardGrid(\'refreshWidget\', widget.widgetid);'.
+						'jQuery(".dashbrd-grid-container").dashboardGrid(\'refreshWidget\', widget.widgetid);'.
 					'}'.
 				'});'.
 
-				'jQuery(".dashbrd-grid-widget-container").dashboardGrid("callWidgetDataShare");'.
+				'jQuery(".dashbrd-grid-container").dashboardGrid("callWidgetDataShare");'.
 
-				'jQuery(".dashbrd-grid-widget-container").dashboardGrid("addAction", "onEditStart", '.
+				'jQuery(".dashbrd-grid-container").dashboardGrid("addAction", "onEditStart", '.
 					'"zbx_sysmap_widget_trigger", "'.$this->uniqueid.'", {'.
 						'parameters: ["onEditStart"],'.
 						'grid: {widget: 1},'.
@@ -195,7 +191,7 @@ class CDashboardWidgetMap extends CDiv {
 		elseif ($this->error !== null && $this->source_type == WIDGET_SYSMAP_SOURCETYPE_FILTER) {
 			$error_msg_html = (new CTableInfo())->setNoDataMessage($this->error);
 			$script_run .=
-				'jQuery(".dashbrd-grid-widget-container").dashboardGrid("addAction", "onDashboardReady", '.
+				'jQuery(".dashbrd-grid-container").dashboardGrid("addAction", "onDashboardReady", '.
 					'"zbx_sysmap_widget_trigger", "'.$this->uniqueid.'", {'.
 						'parameters: ["onDashboardReady", {html: "'. addslashes($error_msg_html).'"}],'.
 						'grid: {widget: 1},'.
@@ -262,17 +258,4 @@ class CDashboardWidgetMap extends CDiv {
 
 		return parent::toString($destroy);
 	}
-
-	/**
-	 * Returns a list of javascript files that are requested to load map widget.
-	 *
-	 * @return array
-	 */
-	public function getScriptFile() {
-		return [
-			'js/vector/class.svg.canvas.js',
-			'js/vector/class.svg.map.js',
-			'js/class.mapWidget.js'
-		];
-	}
 }
