@@ -236,7 +236,7 @@ $form_list
 						->setAttribute('placeholder', _('name'))
 						->setWidth(ZBX_TEXTAREA_TAG_WIDTH),
 					'&rArr;',
-					(new CTextBox('headers[value][#{index}]', '#{value}', $readonly))
+					(new CTextBox('headers[value][#{index}]', '#{value}', $readonly, 1000))
 						->setAttribute('placeholder', _('value'))
 						->setWidth(ZBX_TEXTAREA_TAG_WIDTH),
 					(new CButton(null, _('Remove')))
@@ -291,7 +291,7 @@ $form_list
 		new CLabel(_('HTTP proxy'), 'http_proxy'),
 		(new CTextBox('http_proxy', $data['http_proxy'], $readonly, DB::getFieldLength('items', 'http_proxy')))
 			->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
-			->setAttribute('placeholder', 'http://[user[:password]@]proxy.example.com[:port]'),
+			->setAttribute('placeholder', '[protocol://][user[:password]@]proxy.example.com[:port]'),
 		'http_proxy_row'
 	)
 	// Append ITEM_TYPE_HTTPAGENT HTTP authentication to form list.
@@ -309,17 +309,15 @@ $form_list
 	)
 	// Append ITEM_TYPE_HTTPAGENT User name to form list.
 	->addRow(
-		(new CLabel(_('User name'), 'http_username'))->setAsteriskMark(),
+		new CLabel(_('User name'), 'http_username'),
 		(new CTextBox('http_username', $data['http_username'], $readonly, DB::getFieldLength('items', 'username')))
-			->setAriaRequired()
 			->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH),
 		'http_username_row'
 	)
 	// Append ITEM_TYPE_HTTPAGENT Password to form list.
 	->addRow(
-		(new CLabel(_('Password'), 'http_password'))->setAsteriskMark(),
+		new CLabel(_('Password'), 'http_password'),
 		(new CTextBox('http_password', $data['http_password'], $readonly, DB::getFieldLength('items', 'password')))
-			->setAriaRequired()
 			->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH),
 		'http_password_row'
 	)
